Module settings

Module settings 

Structs

InterwikiSettings
Settings that determine how to turn interwiki links into full URLs.
WikitextSettings
Settings to tweak behavior in the ftml parser and renderer.

Enums

WikitextMode
What mode parsing and rendering is done in.

Statics

DEFAULT_INTERWIKI
An InterwikiSettings instance that has the default prefixes.
EMPTY_INTERWIKI
An InterwikiSettings instance that has no prefixes.