pub fn include<'t, I, E, F>(
input: &'t str,
settings: &WikitextSettings,
includer: I,
invalid_return: F,
) -> Result<(String, Vec<PageRef>), E>Expand description
Replaces the include blocks in a string with the content of the pages referenced by those blocks.